pub fn get_public_randomness_commitment() -> (String, PubRandCommit, Vec<u8>)Expand description
Get public randomness public key, commitment, and signature information
Signature is a Schnorr signature over the commitment
pub fn get_public_randomness_commitment() -> (String, PubRandCommit, Vec<u8>)Get public randomness public key, commitment, and signature information
Signature is a Schnorr signature over the commitment